{ config, pkgs, lib, ... }:

with lib;

{
  home.keyboard = {
    layout = "us";
    options = [ "ctrl:nocaps" "compose:ralt" ];
  };

  xsession.enable = true;

  home.packages = with pkgs;
    let
      gn = pkgs.gnome3;
      evolution = pkgs.evolutionWithPlugins.override {
        plugins = [ pkgs.evolution pkgs.evolution-ews ];
      };
    in [
      keybase-gui

      gn.gnome-tweaks
      mate.atril
      mate.caja
      libreoffice-fresh
      inkscape
      krita
      nyxt
      lagrange
      tor-browser-bundle-bin
      thunderbird
      evolution
      calibre
      atom
      obsidian
      logseq
      flameshot
      gitkraken
      discord

      openshot-qt
      blender
      asunder
      gn.cheese
      vlc
      v4l-utils
      handbrake
      darktable
      pavucontrol
      vorbis-tools
      audacity
      pulseaudio
      jack2
      cadence
      blueman
      blanket

      signal-desktop
      slack
      teams
      zoom-us

      winePackages.full

      nextcloud-client

      iosevka
      fira
      fira-code
      merriweather
      gentium
      gentium-book-basic
      open-sans
      joypixels
      noto-fonts-emoji
      font-awesome
      emojione
      league-of-moveable-type
      corefonts
      vistafonts
      carlito
      caladea
    ];

  home.activation = {
    installFace = lib.hm.dag.entryAfter [ "writeBoundary" ] ''
      $DRY_RUN_CMD cp --force --dereference --no-preserve=ownership $VERBOSE_ARG \
          ${./images/cat.jpg} $HOME/.face
    '';
  };
  xdg.configFile = {
    "wofi".source = ./wofi;
    "kitty/sessions/default.conf".text = ''
      layout tall
      launch ${pkgs.ncmpcpp}/bin/ncmpcpp
      launch ${pkgs.bpytop}/bin/bpytop

      new_tab

      layout tall
      cd ~
    '';
    "waybar".source = ./waybar;
  };

  home.activation = {
    updateFcCache = lib.hm.dag.entryAfter [ "writeBoundary" ] ''
      $DRY_RUN_CMD fc-cache -f
    '';
  };

  programs.wal = {
    enable = true;
    background = pkgs.fetchurl {
      # From Stefanie Buchanan's ArtStation: https://www.artstation.com/artwork/bK0kkn
      urls = [
        "https://cdnb.artstation.com/p/assets/images/images/029/712/149/large/stefanie-buchanan-img-2414.jpg"
        "http://bafybeiff7bjww2dicbqhfubiq67wma6qrjkkndk6s773glwiystzir2goe.ipfs.localhost:8080/"
        "https://bafybeiff7bjww2dicbqhfubiq67wma6qrjkkndk6s773glwiystzir2goe.ipfs.dweb.link/"
      ];
      name = "wallpaper.jpg";
      sha256 =
        "b6b9b88e10715e9e7dfd33dc80ecfff90fa58f0529e6f7c88f67f34991da57e0";
    };
    shell.enable = false;
    sway.enable = true;
  };

  fonts.fontconfig.enable = true;

  gtk = {
    enable = true;

    theme.name = "Equilux";
    theme.package = pkgs.equilux-theme;
    font.name = "Fira Sans Condensed Regular 10";
    font.package = pkgs.fira;
    iconTheme.name = "Flat-Remix-Green-Dark";
    iconTheme.package = pkgs.flat-remix-icon-theme;

    gtk3.extraConfig = {
      gtk-xft-antialias = 1;
      gtk-xft-hinting = 1;
      gtk-xft-hintstyle = "hintmedium";
      gtk-xft-rgba = "rgb";

      gtk-enable-animations = false;
    };
  };

  programs.mako = {
    enable = true;
    defaultTimeout = 10000;
  };

  programs.waybar = {
    enable = true;
    systemd.enable = true;
  };

  services.gammastep = {
    enable = false;
    provider = "manual";
    latitude = 54.0;
    longitude = 1.0;
    tray = true;
  };

  services.redshift = {
    enable = true;
    provider = "manual";
    latitude = 54.0;
    longitude = 1.0;
    tray = true;
  };

  programs.kitty = {
    enable = true;
    font = {
      name = "Iosevka Medium";
      package = pkgs.iosevka;
      size = 11;
    };
    settings = {
      allow_remote_control = true;
      listen_on = "unix:\${XDG_RUNTIME_DIR}/kitty.sock";

      enable_audio_bell = false;
      visual_bell_duration = "0.1";
    };
    extraConfig = ''
      include ${./colours/Monokai.conf}
    '';
  };

  programs.rofi = {
    enable = true;
    plugins = [ pkgs.rofi-emoji pkgs.rofi-pass ];
    theme = "gruvbox-dark-soft";
    terminal = pkgs.alacritty + /bin/alacritty;
  };

  programs.chromium.enable = true;
  programs.chromium.package = pkgs.ungoogled-chromium;
  programs.qutebrowser.enable = true;
  programs.element-desktop.enable = true;

  programs.obs-studio = {
    enable = true;
    plugins = with pkgs.obs-studio-plugins; [ wlrobs ];
  };

  programs.ncmpcpp.settings = { user_interface = "alternative"; };

  services.syncthing.enable = true;
  services.nextcloud-client.enable = true;
}
